# -*- coding: utf-8 -*-
# Elisa - Home multimedia server
# Copyright (C) 2006,2007 Fluendo Embedded S.L. (www.fluendo.com).
# All rights reserved.
#
# This file is available under one of two license agreements.
#
# This file is licensed under the GPL version 2.
# See "LICENSE.GPL" in the root of this distribution including a special
# exception to use Elisa with Fluendo's plugins.
#
# The GPL part of Elisa is also available under a commercial licensing
# agreement from Fluendo.
# See "LICENSE.Elisa" in the root directory of this distribution package
# for details on that license.


__maintainer__ = 'Lionel Martin <lionel@fluendo.com>'


from elisa.core.component import Component
from elisa.core.utils import classinit

class Context(Component):

    # it's the main window instance
    #  for pigment, it's the viewport
    #  for gtk, it's the window
    viewport_handle = None
    """
    It is public. So If you have to do things, when it is changed from the
    outside use these methods to do this:
    viewport_handle__get, viewport_handle__set
    """

    # it's the first instance to add to the window
    # returned by the root view
    #  for pigment, it's a group
    #  for gtk, it's a Box
    # FIXME: rename that to something sensible
    context_handle = None
    """
    It is public. So If you have to do things, when it is changed from the
    outside use these methods to do this:
    context_handle__get, context_handle__set
    """


    # it's the instance for retrieve input
    # passed by the interface controller to the input_provider
    #  for pigment, it's the viewport
    input_events_handle = None 
    """
    It is public. So If you have to do things, when it is changed from the
    outside use these methods to do this:
    input_events_handle__get, input_events_handle__set
    """
    
    input_events_handle = None 
    """
    It is public. So If you have to do things, when it is changed from the
    outside use these methods to do this:
    input_events_handle__get, input_events_handle__set
    """
    
    def __init__(self):
        Component.__init__(self)
        self._aspect_ratio = None


    def update(self):
        """
        This method is called by the interface_controller in a certain
        interval. It should renew the viewport, so that the user can see the
        changes.
        """
        pass


    def aspect_ratio__get(self):
        return self._aspect_ratio
    
    
    def aspect_ratio__set(self, value):
        """
        can be '16:9', 'auto', 'mm'
        """
                    
        if self._aspect_ratio == value:
            return
        
        if value not in ('auto', 'mm') and not isinstance(value.split(':'), tuple) and len(value.split(':')) != 2:
            raise TypeError
        
        self._aspect_ratio = value
        
        self.aspect_ratio_changed(value)
       
        
    def aspect_ratio_changed(self, aspect_ratio):
        pass