# -*- coding: utf-8 -*-
# Elisa - Home multimedia server
# Copyright (C) 2006,2007 Fluendo Embedded S.L. (www.fluendo.com).
# All rights reserved.
#
# This file is available under one of two license agreements.
#
# This file is licensed under the GPL version 2.
# See "LICENSE.GPL" in the root of this distribution including a special
# exception to use Elisa with Fluendo's plugins.
#
# The GPL part of Elisa is also available under a commercial licensing
# agreement from Fluendo.
# See "LICENSE.Elisa" in the root directory of this distribution package
# for details on that license.


__maintainer__ = 'Lionel Martin <lionel@fluendo.com>'
__maintainer2__ = 'Florian Boucault <florian@fluendo.com>'


from elisa.core.component import Component
from elisa.core.observers.observable import Observable


class Model(Component, Observable):
    """
    A Model is a Component holding data that can be rendered by several Views.
    It is provided by Activity Components which have data to display.
    Models can inherit from each other and can compose other Models.

    A Model is exposable on the network so that a remote View from another
    Elisa instance can display its content.

    @ivar activity:        reference to the activity which created the Model
    @type activity:        L{elisa.base_components.activity.Activity}
    @ivar activate_action: action fired when the Model gets activated
    @type activate_action: L{elisa.base_components.action.Action}
    @ivar hover_action:   action fired when the Model gets hovered
    @type hover_action:   L{elisa.base_components.action.Action}
    """

    def __init__(self):
        Component.__init__(self)
        Observable.__init__(self)

        self.activity = None
        # FIXME: do the actions really need to be in Model class ?
        self.activate_action = None
        self.hover_action = None
        self.parent = None
        self.loading = False
