# -*- coding: utf-8 -*-
# Elisa - Home multimedia server
# Copyright (C) 2006,2007 Fluendo Embedded S.L. (www.fluendo.com).
# All rights reserved.
#
# This file is available under one of two license agreements.
#
# This file is licensed under the GPL version 2.
# See "LICENSE.GPL" in the root of this distribution including a special
# exception to use Elisa with Fluendo's plugins.
#
# The GPL part of Elisa is also available under a commercial licensing
# agreement from Fluendo.
# See "LICENSE.Elisa" in the root directory of this distribution package
# for details on that license.


__maintainer__ = 'Lionel Martin <lionel@fluendo.com>'

from elisa.core.utils import classinit
from elisa.core import log


class Backend(log.Loggable):
    """
    DOCME
    """

    __metaclass__ = classinit.ClassInitMeta
    __classinit__ = classinit.build_properties

    def __init__(self, controller):
        log.Loggable.__init__(self)
        # FIXME: view, context and theme are set only once: is that wise ?
        self._controller = controller
        self._focused_controller = None


    def controller__get(self):
        """
        Return the controller for this backend
        @rtype:     controller
        """
        return self._controller


    def focused_controller__get(self):
        """
        Returns the controller on which the focus is
        @rtype      controller
        """
        return self._focused_controller


    def focused_controller__set(self, controller):
        """
        DOCME
        """
        previous_controller = self._focused_controller
        self._focused_controller = controller

        controller_to_focus = self._get_branch(controller)

        # notify focus removing
        for no_focus_controller in self._get_branch(previous_controller):
            if no_focus_controller not in controller_to_focus:
                no_focus_controller.focused = False

        # notify focus
        for to_focus_controller in controller_to_focus:
            to_focus_controller.focused = True


    def has_focus(self, controller):
        """
        DOCME
        """
        if self._focused_controller == controller:
            return True
        current_controller = self._focused_controller
        while current_controller.parent != None:
            current_controller = current_controller.parent
            if controller == current_controller:
                return True
        return False


    def _get_branch(self, leaf):
        """
        return all the parent of the leaf
        and the leaf
        """

        if leaf == None:
            return []

        branch = [leaf]
        current_controller = leaf
        while current_controller.parent != None:
            current_controller = current_controller.parent
            branch.append(current_controller)
        return branch


    def get_focused_child(self, controller):
        """
        DOCME
        """
        if self._focused_controller == None:
            return None

        current_controller = self._focused_controller
        if controller == current_controller.parent:
            return current_controller

        while current_controller.parent != None:
            current_controller = current_controller.parent
            if controller == current_controller.parent:
                return current_controller
        return None


    def _update_parent_focus(self, leaf, focus):
        current_controller = leaf
        current_controller.focused = focus
        while current_controller.parent != None:
            current_controller = current_controller.parent
            current_controller.focused = focus
