# -*- coding: utf-8 -*-
# Elisa - Home multimedia server
# Copyright (C) 2006,2007 Fluendo Embedded S.L. (www.fluendo.com).
# All rights reserved.
#
# This file is available under one of two license agreements.
#
# This file is licensed under the GPL version 2.
# See "LICENSE.GPL" in the root of this distribution including a special
# exception to use Elisa with Fluendo's plugins.
#
# The GPL part of Elisa is also available under a commercial licensing
# agreement from Fluendo.
# See "LICENSE.Elisa" in the root directory of this distribution package
# for details on that license.


__maintainer__ = 'Lionel Martin <lionel@fluendo.com>'

from elisa.core.utils import classinit, signal
from elisa.core import log
from elisa.core import plugin_registry
from elisa.base_components.theme import Theme
from elisa.core import common

from twisted.internet import defer


class Frontend(log.Loggable):
    """
    DOCME
    """

    __metaclass__ = classinit.ClassInitMeta
    __classinit__ = classinit.build_properties
    
    theme_changed = signal.Signal('theme_changed', Theme)

    name = None

    def __init__(self, context, view, theme):
        log.Loggable.__init__(self)
        self._view = view
        self._context = context
        self._theme = theme

    def view__get(self):
        """
        Return the View of this Frontend
        @rtype:     view FIXME
        """
        return self._view

    def context__get(self):
        """
        Get the Context of this Frontend
        @rtpye:     context FIXME
        """
        return self._context

    def theme__get(self):
        """
        Get the theme of this Frontend
        @rtype:     theme FIXME
        """
        return self._theme
    
    def change_theme(self, theme_path):
        """
        change the theme of the frontend
        """
        
        if self._theme and self._theme.path == theme_path:
            #try to change to the same theme
            return
        
        try:
            pr = common.application.plugin_registry
            theme = pr.create_component(theme_path)
            application = common.application
            application.config.set_option('theme', theme_path, section=self.name)
        except:
            self.warning("Cannot create theme %r for frontend %r", theme_path,
                         self.name)
            raise
        
        self._theme = theme
        # Why are we using a Signal here instead of a Message?
        self.theme_changed.emit(theme)
        

    def update(self):
        """
        DOCME
        """
        if self._context:
            self._context.update()

    def clean(self):
        """
        DOCME
        """
        # the cleanups have to be chained (in a sequence)
        dfr = defer.Deferred()
        dfr.addCallback(lambda x: self._view.clean())
        dfr.addCallback(lambda x: self._theme.clean())
        dfr.addCallback(lambda x: self._context.clean())
        dfr.callback(None)
        return dfr
