# -*- coding: utf-8 -*-
# Elisa - Home multimedia server
# Copyright (C) 2006,2007 Fluendo Embedded S.L. (www.fluendo.com).
# All rights reserved.
#
# This file is available under one of two license agreements.
#
# This file is licensed under the GPL version 2.
# See "LICENSE.GPL" in the root of this distribution including a special
# exception to use Elisa with Fluendo's plugins.
#
# The GPL part of Elisa is also available under a commercial licensing
# agreement from Fluendo.
# See "LICENSE.Elisa" in the root directory of this distribution package
# for details on that license.


import cgitb, os, sys, smtplib
from email.MIMEMultipart import MIMEMultipart
from email.MIMEText import MIMEText
from email.Header import Header

class NullFile:

    def write(self, data):
        pass

class TracebackHook(cgitb.Hook):


    def handle(self, info=None):
        """ add-on to default cgitb.handle():

        - if logdir doesn't exists, create it
        - if format == mail, send traceback via mail
        """
        if not os.path.exists(self.logdir):
            os.makedirs(self.logdir)


        info = info or sys.exc_info()
        if self.format == "html":
            self.file.write(reset())

        formatter = (self.format=="html") and cgitb.html or cgitb.text
        plain = False
        try:
            doc = formatter(info, self.context)
        except:
            import traceback
            doc = ''.join(traceback.format_exception(*info))
            plain = True

        if self.display:
            self.file.write(doc + '\n')
        else:
            self.file.write('A problem occurred in Elisa.\n')

        if self.logdir is not None:
            import tempfile
            suffix = ['.txt', '.html'][self.format=="html"]
            (fd, path) = tempfile.mkstemp(suffix=suffix, prefix="elisa_",
                                          dir=self.logdir)
            try:
                file = os.fdopen(fd, 'w')
                file.write(doc)
                file.close()
                msg = '%s contains the description of this error.' % path
            except:
                msg = 'Tried to save traceback to %s, but failed.' % path
            self.file.write(msg + '\n')
        try:
            self.file.flush()
        except: pass




class EmailTracebackHook(TracebackHook):

    email_send = False

    def set_mail_parameters(self, author, recipients, subject, smtp_server):
        self.mail_from = author
        self.mail_to = recipients
        self.mail_subject = subject
        self.smtp_server = smtp_server
        self.email_send = True

    def get_last_tb(self):
        """ Fetch the last traceback data in logdir and purge the
        directory. Thus we are sure there is only one traceback in the
        directory at a time.
        """
        files = os.listdir(self.logdir)
        assert len(files) == 1
        path = os.path.join(self.logdir, files[0])
        f = open(path)
        tb = f.read()
        os.unlink(path)
        return tb

    def handle(self, info=None):
        TracebackHook.handle(self, info=info)
        if self.format == 'mail':
            self.send_mail(self.get_last_tb())

    def send_mail(self, mail_data):
        if self.email_send:
            print 'Sending traceback via mail ...'
        else:
            print mail_data
            return

        subject = self.mail_subject
        sender = self.mail_from
        recipients = self.mail_to
        encoding = 'iso-8859-1'

        if not mail_data:
            return

        msg = MIMEMultipart("alternative")

        msg['Subject'] = Header(subject, encoding)
        msg['To'] = str(recipients)[1:-1].replace('\'','')
        msg['MIME-Version'] = "1.0"
        msg.epilogue = ''

        textPart = MIMEText(mail_data,encoding)
        msg.attach(textPart)

        server = smtplib.SMTP(self.smtp_server)
        try:
            server.sendmail(sender, recipients, msg.as_string())
        except smtplib.SMTPRecipientsRefused,msg:
            print 'mail was refused by smtp server'
        server.quit()


def set_exception_hook(mail_from, mail_to, mail_subject, smtp_server):
    " override the default exception hook with out customized one "
    print 'set exception hook'
    hook = EmailTracebackHook(file=NullFile(), display=0,
                              logdir='tracebacks', format='mail')
    hook.set_mail_parameters(mail_from, mail_to, mail_subject, smtp_server)
    sys.excepthook = hook

