# -*- coding: utf-8 -*-
# Elisa - Home multimedia server
# Copyright (C) 2006,2007 Fluendo Embedded S.L. (www.fluendo.com).
# All rights reserved.
#
# This file is available under one of two license agreements.
#
# This file is licensed under the GPL version 2.
# See "LICENSE.GPL" in the root of this distribution including a special
# exception to use Elisa with Fluendo's plugins.
#
# The GPL part of Elisa is also available under a commercial licensing
# agreement from Fluendo.
# See "LICENSE.Elisa" in the root directory of this distribution package
# for details on that license.

"""
GstElisaDiscoverer class
"""


__maintainer__ = 'Florian Boucault <florian@fluendo.com>'

import gst, gobject, time
# FIXME: should not use gnomevfs
import gnomevfs

from gst.extend.discoverer import Discoverer

class GstElisaDiscoverer(Discoverer):

    def __init__(self, uri):
        gobject.GObject.__init__(self)

        self.mimetype = None

        self.audiocaps = {}
        self.videocaps = {}

        self.videowidth = 0
        self.videoheight = 0
        self.videorate = gst.Fraction(0,1)

        self.audiofloat = False
        self.audiorate = 0
        self.audiodepth = 0
        self.audiowidth = 0
        self.audiochannels = 0

        self.audiolength = 0L
        self.videolength = 0L

        self.is_video = False
        self.is_audio = False

        self.otherstreams = []

        self.finished = False
        self.tags = {}
        self._success = False
        self._dfr = None

        self._timeoutid = 0

        self.uri = uri

        # the initial elements of the pipeline
        # FIXME: why not 'filename = uri.path' ?
        _, filename = repr(uri).split('://')
        # FIXME: should use MediaProvider
        filename = gnomevfs.escape_host_and_path_string(filename)

        # FIXME: gst source element should come from the MediaProvider
        if uri.scheme == 'file':
            self.src = gst.element_factory_make('filesrc')
            self.src.set_property("blocksize", 1000000)
        else:
            self.src = gst.element_factory_make('gnomevfssrc')

        self.src.set_property("location", filename)
        self.dbin = gst.element_factory_make("decodebin")
        self.add(self.src, self.dbin)
        self.src.link(self.dbin)
        self.typefind = self.dbin.get_by_name("typefind")

        # callbacks
        self.typefind.connect("have-type", self._have_type_cb)
        self.dbin.connect("new-decoded-pad", self._new_decoded_pad_cb)
        self.dbin.connect("unknown-type", self._unknown_type_cb)
