# -*- coding: utf-8 -*-
# Elisa - Home multimedia server
# Copyright (C) 2006,2007 Fluendo Embedded S.L. (www.fluendo.com).
# All rights reserved.
#
# This file is available under one of two license agreements.
#
# This file is licensed under the GPL version 2.
# See "LICENSE.GPL" in the root of this distribution including a special
# exception to use Elisa with Fluendo's plugins.
#
# The GPL part of Elisa is also available under a commercial licensing
# agreement from Fluendo.
# See "LICENSE.Elisa" in the root directory of this distribution package
# for details on that license.

"""
Miscellaneaous utilities that don't need their own module because they are
reasonnably small.
"""
import mimetypes
import sys
import socket
import fcntl
import struct
import os, re

def env_var_expand(data):
    """

    $HOME -> /home/user
    
    """
    if sys.platform == 'win32':
        re_env = re.compile(r'%\w+%')
        def expander(mo):
            return os.environ.get(mo.group()[1:-1], 'UNKNOWN')

        expanded = re_env.sub(expander, data)
    else:
        expanded = data
        for name, value in os.environ.iteritems():
            index = expanded.find('$%s' % name)
            if index > -1:
                expanded = re.sub('\$%s' % name, value, expanded)
    return expanded

def un_camelify(camel_string):
    """

    FooBar -> foo_bar

    """

    if len(camel_string) < 2:
        return camel_string

    un_cameled = camel_string[0].lower()
    for letter in camel_string[1:]:
        if letter.isupper():
            un_cameled += '_%s' % letter.lower()
        else:
            un_cameled += letter
    return un_cameled

def get_media_infos_from_mime(uri):
    mime_type = mimetypes.guess_type(uri.path)
    if mime_type[0]:
        parts = mime_type[0].split('/')
        mime_type = mime_type[0]
        # Special cases handling
        if parts[0] == 'application':
            ext = uri.extension
            custom_extensions = {'ogg': 'audio',
                                 }
            file_type = custom_extensions.get(ext)
        else:
            file_type = parts[0]

        blacklist = ['x-mpegurl',]
        if parts[1] in blacklist:
            mime_type = ''
            file_type = ''
    else:
        # in case mimetypes did not return anything, filter on extension
        custom_extensions = {'flv': 'video',
                             'ogm': 'video',
                             'mkv': 'video'
                             }
        file_type = custom_extensions.get(uri.extension)
    return mime_type, file_type


def get_host_address_win():
    s = socket.gethostname()
    return socket.gethostbyname(s)

def get_host_address_posix():
    route_file = '/proc/net/route'
    route = open(route_file)
    host_address = '127.0.0.1'
    if route:
        tmp = route.readline() #skip first line
        while tmp != '':
            tmp = route.readline()
            l = tmp.split('\t')
            if len(l) > 2:
                if l[2] != '00000000': #default gateway...
                    route.close()
                    host_address = get_ip_address(l[0])
                    break

        route.close()
    return host_address

def get_host_address():
    if sys.platform == "win32":
        return get_host_address_win()
    else:
        return get_host_address_posix()

def get_posix_ip_address(ifname):
    if not ifname:
        ip_address = '127.0.0.1'
    else:
        s = socket.socket(socket.AF_INET, socket.SOCK_DGRAM)
        ip_address = socket.inet_ntoa(fcntl.ioctl(
            s.fileno(),
            0x8915,  # SIOCGIFADDR
            struct.pack('256s', ifname[:15])
            )[20:24])
    return ip_address

def get_win32_ipaddress(ifname):
    # FIXME: to implement
    return ""

def get_ip_address(ifname):
    if sys.platform == "win32":
        return get_win32_ip_address(ifname)
    else:
        return get_posix_ip_address(ifname)
