# -*- coding: utf-8 -*-
# Elisa - Home multimedia server
# Copyright (C) 2006,2007 Fluendo Embedded S.L. (www.fluendo.com).
# All rights reserved.
#
# This file is available under one of two license agreements.
#
# This file is licensed under the GPL version 2.
# See "LICENSE.GPL" in the root of this distribution including a special
# exception to use Elisa with Fluendo's plugins.
#
# The GPL part of Elisa is also available under a commercial licensing
# agreement from Fluendo.
# See "LICENSE.Elisa" in the root directory of this distribution package
# for details on that license.


__maintainer__ = 'Lionel Martin <lionel@fluendo.com>'


from elisa.core import common
from elisa.core.plugin_registry import PluginNotFound, ComponentNotFound
from elisa.core import plugin_registry

from elisa.core.media_uri import MediaUri

MenuActivityClass = plugin_registry.get_component_class('base:menu_activity')
from switch_aspect_ratio_action import SwitchAspectRatioAction

class AspectRatioSwitcherActivity(MenuActivityClass):
    """
    This class manage the aspect ratio switching activity
    """
    config_doc = {'aspect_ratios': "a list of aspect ratio 'plugin:component' like '16:9' or 'auto'"}
    default_config = {'aspect_ratios': ['auto', '4:3', '16:9', '16:10', 'mm']}

    menu_name = "Aspect ratio switching"
    menu_icon_name = "aspect_ratio_switcher"
    media_types = []
    
    def get_model(self):
        """
        Returns a menu_node_model for the Theme menu
        """
        registry = common.application.plugin_registry
        main_node = MenuActivityClass.get_model(self)
        
        for aspect_ratio in self.config.get("aspect_ratios" , []):
            self.log("create aspect ratio menu model %s", aspect_ratio)
            
            if aspect_ratio == 'auto':
                label = 'use screen resolution'
            elif aspect_ratio == 'mm':
                label = 'use screen size'
            else:
                label = aspect_ratio
                
            menu_model = self._create_menu_model(label, 'aspect_ratio')
            action = SwitchAspectRatioAction()
            action.aspect_ratio = aspect_ratio
            menu_model.activate_action = action
            
            if menu_model != None:
                self.log("menu model: %r", menu_model)
                main_node.append(menu_model)
            else:
                self.debug("error when creating menu_model %s", aspect_ratio)

        main_node.has_children = len(main_node) > 0
        
        return main_node

