# -*- coding: utf-8 -*-
# Elisa - Home multimedia server
# Copyright (C) 2006,2007 Fluendo Embedded S.L. (www.fluendo.com).
# All rights reserved.
#
# This file is available under one of two license agreements.
#
# This file is licensed under the GPL version 2.
# See "LICENSE.GPL" in the root of this distribution including a special
# exception to use Elisa with Fluendo's plugins.
#
# The GPL part of Elisa is also available under a commercial licensing
# agreement from Fluendo.
# See "LICENSE.Elisa" in the root directory of this distribution package
# for details on that license.


__maintainer__ = 'Lionel Martin <lionel@fluendo.com>'


from elisa.base_components.action import Action
from elisa.core.media_uri import MediaUri
from elisa.core import media_uri, player
from elisa.core import plugin_registry

class EnqueueAction(Action):
    """
    Play mediafile
    """

    label='euqueue'
    _supported_file_types=('audio', 'video')

    #Attribute to set at initialization
    #MediaURI instance
    uri=None
    #position to add the uri in playlist
    #-1 : add at the end.
    position=-1
    #listmodel instance
    player_model=None

    #Options:
    #if true, the playlist will be played after uri adding from the begining
    play_now=True
    #if true, the playlist will be removed before adding the new uri
    erase_before_enqueue=True


    def __call__(self, controller, origin=None):
        """
        @raise TypeError: When action has incorrect parameters
        """
        PlayerModelClass = plugin_registry.get_component_class('base:player_model')
        if isinstance(self.uri, MediaUri) and isinstance(self.player_model, PlayerModelClass):
            playlist_model = self.player_model.playlist
            playlist_activity = playlist_model.activity

            if playlist_activity==None:
                raise TypeError("action %s have incorrect parameters" % self.name)

            if self.erase_before_enqueue:
                playlist_activity.empty()

            playlist_activity.add_uri(self.uri, -1)

            if self.play_now==True:

                def play_now(model):
                    if len(model):
                        uri = model[0]
                        self.player_model.uri = uri
                        self.player_model.state = player.STATES.PLAYING

                # load items in the playlist
                dfr = playlist_activity.loadmore(self.uri, playlist_model)
                dfr.addCallback(play_now)

        else:
            raise TypeError("action %s have incorrect parameters" % self.name)
