# -*- coding: utf-8 -*-
# Elisa - Home multimedia server
# Copyright (C) 2006,2007 Fluendo Embedded S.L. (www.fluendo.com).
# All rights reserved.
#
# This file is available under one of two license agreements.
#
# This file is licensed under the GPL version 2.
# See "LICENSE.GPL" in the root of this distribution including a special
# exception to use Elisa with Fluendo's plugins.
#
# The GPL part of Elisa is also available under a commercial licensing
# agreement from Fluendo.
# See "LICENSE.Elisa" in the root directory of this distribution package
# for details on that license.


__maintainer__ = 'Lionel Martin <lionel@fluendo.com>'
__maintainer2__ = 'Florian Boucault <florian@fluendo.com>'


from elisa.base_components.controller import Controller
from twisted.internet import reactor
from elisa.core.input_event import *


class SlideshowController(Controller):

    supported_models = ('base:slideshow_model')
    default_associations = (
    ('base:list_model','base:list_controller'),
    )

    uri = None
    playing = False

    def __init__(self):
        Controller.__init__(self)
        self._call_later = None

    def model_changed(self):
        self.uri = self.model.uri
        self.playing = self.model.playing

    """
    def handle_input(self, input_event):
        if input_event.action == EventAction.GO_LEFT:
            if len(self.model.playlist) > 0:
                self.previous_image()
                
            return False

        elif input_event.action == EventAction.GO_RIGHT:
            if len(self.model.playlist) > 0:
                self.next_image()
            return False
            
        return True
    """
    
    def attribute_set(self, key, value):
        Controller.attribute_set(self, key, value)
        if key == 'uri':
            self.uri = value
            if self.model.playing and not self.model.preview_mode and self.focused == False:
                self.focus()
        elif key == 'playing':
            self.playing = value
            if self.model.playing and not self.model.preview_mode:
                self.focus()
                self._call_later = reactor.callLater(self.model.duration, self.next_image)

    def _cancel_last_call_later(self):
        if self._call_later and self._call_later.cancelled == False and self._call_later.called == False:
                self._call_later.cancel()

    def focus_changed(self, value):
        if value == False and self.model.playing == True:
            self._cancel_last_call_later()
            self.model.playing = False


    def next_image(self):
        self._cancel_last_call_later()
        current_uri = self.model.uri
        playlist = self.model.playlist
        if current_uri in playlist:
            index = playlist.index(current_uri) + 1
            if index < len(playlist):
                self.model.uri = playlist[index]
                if self.model.playing == True:
                    self._call_later = reactor.callLater(self.model.duration, self.next_image)
                    
                    
    def previous_image(self):
        self._cancel_last_call_later()
        current_uri = self.model.uri
        playlist = self.model.playlist
        if current_uri in playlist:
            index = playlist.index(current_uri) - 1
            if index < len(playlist) and index >= 0:
                self.model.uri = playlist[index]
                if self.model.playing == True:
                    self._call_later = reactor.callLater(self.model.duration, self.previous_image)
