# -*- coding: utf-8 -*-
# Elisa - Home multimedia server
# Copyright (C) 2006,2007 Fluendo Embedded S.L. (www.fluendo.com).
# All rights reserved.
#
# This file is available under one of two license agreements.
#
# This file is licensed under the GPL version 2.
# See "LICENSE.GPL" in the root of this distribution including a special
# exception to use Elisa with Fluendo's plugins.
#
# The GPL part of Elisa is also available under a commercial licensing
# agreement from Fluendo.
# See "LICENSE.Elisa" in the root directory of this distribution package
# for details on that license.


__maintainer__ = 'Lionel Martin <lionel@fluendo.com>'
__maintainer2__ = 'Florian Boucault <florian@fluendo.com>'


from elisa.core import plugin_registry, common
from pypgmtools.widgets.image_transition import ImageTransition
import pgm, os
import tempfile

SlideshowViewClass = plugin_registry.get_component_class('base:slideshow_view')


class SlideshowView(SlideshowViewClass):

    supported_controllers = ('base:slideshow_controller')

    def __init__(self):
        SlideshowViewClass.__init__(self)
        self.group = None
        self.image_tr = None

    def frontend_changed(self, previous_frontend, new_frontend):
        SlideshowViewClass.frontend_changed(self, previous_frontend,
                                            new_frontend)

        if self.image_tr == None:
            canvas = self.frontend.context.viewport_handle.get_canvas()
            self.image_tr = ImageTransition(canvas, pgm.DRAWABLE_MIDDLE)
            self.image_tr.visible = True

            self.context_handle = self.image_tr

    def uri_changed(self, uri):
        # FIXME : works only with localfs: should ask the media manager to
        # download the pictures in a local cache before sending it to
        # ImageTransition
        uri = common.application.media_manager.get_real_uri(uri)
        path = None
        if uri.scheme == 'file':
            path = uri.path
        else:
            # FIXME: not yet convenient solution to the FIXME above :(
            media_manager = common.application.media_manager
            handle = media_manager.blocking_open(uri)
            if handle:
                fd, path = tempfile.mkstemp(suffix=uri.extension)
                self.debug("Caching data to %r", path)
                data = handle.blocking_read()
                os.write(fd, data)
                os.close(fd)
                handle.blocking_close()
        if path:
            self.image_tr.current_image_path = path
            self.image_tr.opacity = 255
